@@ -10,7 +10,6 @@
 * @license http://opensource.org/licenses/lgpl-license.php GNU Lesser General Public License Version 2.1
 *
 * @package Krumo
-* @version $Id: class.krumo.php,v 1.1.2.5 2009/09/23 18:14:19 davereid Exp $
 */
 
 //////////////////////////////////////////////////////////////////////////////
@@ -67,7 +66,7 @@ Class krumo {
 	* @access public
 	* @static
 	*/
-	Function version() {
+  static Function version() {
 		return '0.2a';
 		}
 
@@ -79,7 +78,7 @@ Class krumo {
 	* @access public
 	* @static
 	*/
-	Function backtrace() {
+  static Function backtrace() {
 
 		// disabled ?
 		//
@@ -98,7 +97,7 @@ Class krumo {
 	* @access public
 	* @static
 	*/
-	Function classes() {
+  static Function classes() {
 
 		// disabled ?
 		//
@@ -122,7 +121,7 @@ This is a list of all currently declared classes.
 	* @access public
 	* @static
 	*/
-	Function interfaces() {
+  static Function interfaces() {
 
 		// disabled ?
 		//
@@ -146,7 +145,7 @@ This is a list of all currently declared interfaces.
 	* @access public
 	* @static
 	*/
-	Function includes() {
+  static Function includes() {
 
 		// disabled ?
 		//
@@ -170,7 +169,7 @@ This is a list of all currently included (or required) files.
 	* @access public
 	* @static
 	*/
-	Function functions() {
+  static Function functions() {
 
 		// disabled ?
 		//
@@ -194,7 +193,7 @@ This is a list of all currently declared functions.
 	* @access public
 	* @static
 	*/
-	Function defines() {
+  static Function defines() {
 
 		// disabled ?
 		//
@@ -218,7 +217,7 @@ This is a list of all currently declared constants (defines).
 	* @access public
 	* @static
 	*/
-	Function extensions() {
+  static Function extensions() {
 
 		// disabled ?
 		//
@@ -242,7 +241,7 @@ This is a list of all currently loaded PHP extensions.
 	* @access public
 	* @static
 	*/
-	Function headers() {
+  static Function headers() {
 
 		// disabled ?
 		//
@@ -266,7 +265,7 @@ This is a list of all HTTP request headers.
 	* @access public
 	* @static
 	*/
-	Function phpini() {
+  static Function phpini() {
 
 		// disabled ?
 		//
@@ -290,7 +289,7 @@ This is a list of the configuration settings read from <code><b><?php echo get_c
 	* @access public
 	* @static
 	*/
-	Function conf() {
+  static Function conf() {
 
 		// disabled ?
 		//
@@ -314,7 +313,7 @@ This is a list of all your configuration settings.
 	* @access public
 	* @static
 	*/
-	Function path() {
+  static Function path() {
 
 		// disabled ?
 		//
@@ -338,7 +337,7 @@ This is a list of the specified directories under your <code><b>include_path</b>
 	* @access public
 	* @static
 	*/
-	Function request() {
+  static Function request() {
 
 		// disabled ?
 		//
@@ -362,7 +361,7 @@ This is a list of all the values from the <code><b>$_REQUEST</b></code> array.
 	* @access public
 	* @static
 	*/
-	Function get() {
+  static Function get() {
 
 		// disabled ?
 		//
@@ -386,7 +385,7 @@ This is a list of all the values from the <code><b>$_GET</b></code> array.
 	* @access public
 	* @static
 	*/
-	Function post() {
+  static Function post() {
 
 		// disabled ?
 		//
@@ -410,7 +409,7 @@ This is a list of all the values from the <code><b>$_POST</b></code> array.
 	* @access public
 	* @static
 	*/
-	Function server() {
+  static Function server() {
 
 		// disabled ?
 		//
@@ -434,7 +433,7 @@ This is a list of all the values from the <code><b>$_SERVER</b></code> array.
 	* @access public
 	* @static
 	*/
-	Function cookie() {
+  static Function cookie() {
 
 		// disabled ?
 		//
@@ -458,7 +457,7 @@ This is a list of all the values from the <code><b>$_COOKIE</b></code> array.
 	* @access public
 	* @static
 	*/
-	Function env() {
+  static Function env() {
 
 		// disabled ?
 		//
@@ -482,7 +481,7 @@ This is a list of all the values from the <code><b>$_ENV</b></code> array.
 	* @access public
 	* @static
 	*/
-	Function session() {
+  static Function session() {
 
 		// disabled ?
 		//
@@ -508,7 +507,7 @@ This is a list of all the values from the <code><b>$_SESSION</b></code> array.
 	* @access public
 	* @static
 	*/
-	Function ini($ini_file) {
+  static Function ini($ini_file) {
 
 		// disabled ?
 		//
@@ -541,7 +540,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access public
 	* @static
 	*/
-	Function dump($data) {
+  static Function dump($data) {
 
 		// disabled ?
 		//
@@ -626,7 +625,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _css() {
+  static Function _css() {
 		
 		static $_css = false;
 		
@@ -704,7 +703,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access public
 	* @static
 	*/
-	Function enable() {
+  static Function enable() {
 		return true === krumo::_debug(true);
 		}
 
@@ -715,7 +714,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access public
 	* @static
 	*/
-	Function disable() {
+  static Function disable() {
 		return false === krumo::_debug(false);
 		}
 	
@@ -727,7 +726,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _debug($state=null) {
+  static Function _debug($state=null) {
 		
 		static $_ = true;
 		
@@ -752,7 +751,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _dump(&$data, $name='...') {
+  static Function _dump(&$data, $name='...') {
 
 		// object ?
 		//
@@ -831,14 +830,15 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _null($name) {
+  static Function _null($name) {
 ?>
 <li class="krumo-child">
 	<div class="krumo-element"
 		onMouseOver="krumo.over(this);"
 		onMouseOut="krumo.out(this);">
 		
-			<a class="krumo-name"><?php echo $name;?></a>
+			<?php /* DEVEL: added htmlSpecialChars */ ?>
+			<a class="krumo-name"><?php echo htmlSpecialChars($name);?></a>
 			(<em class="krumo-type krumo-null">NULL</em>) 
 	</div>
 </li>
@@ -855,7 +855,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _marker() {
+  static Function _marker() {
 		
 		static $_recursion_marker;
 		if (!isset($_recursion_marker)) {
@@ -877,7 +877,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function &_hive(&$bee) {
+  static Function &_hive(&$bee) {
 		
 		static $_ = array();
 
@@ -909,7 +909,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _vars(&$data) {
+  static Function _vars(&$data) {
 
 		$_is_object = is_object($data);
 		
@@ -984,7 +984,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _recursion() {
+  static Function _recursion() {
 ?>
 <div class="krumo-nest" style="display:none;">
 	<ul class="krumo-node">
@@ -1012,7 +1012,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _array(&$data, $name) {
+  static Function _array(&$data, $name) {
 ?>
 <li class="krumo-child">
 	
@@ -1021,7 +1021,8 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 		onMouseOver="krumo.over(this);"
 		onMouseOut="krumo.out(this);">
 		
-			<a class="krumo-name"><?php echo $name;?></a>
+			<?php /* DEVEL: added htmlSpecialChars */ ?>
+			<a class="krumo-name"><?php echo htmlSpecialChars($name);?></a>
 			(<em class="krumo-type">Array, <strong class="krumo-array-length"><?php echo 
 				(count($data)==1)
 					?("1 element")
@@ -1063,7 +1064,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _object(&$data, $name) {
+  static Function _object(&$data, $name) {
 ?>
 <li class="krumo-child">
 
@@ -1072,7 +1073,8 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 		onMouseOver="krumo.over(this);"
 		onMouseOut="krumo.out(this);">
 
-			<a class="krumo-name"><?php echo $name;?></a>
+			<?php /* DEVEL: added htmlSpecialChars */ ?>
+			<a class="krumo-name"><?php echo htmlSpecialChars($name);?></a>
 			(<em class="krumo-type">Object</em>) 
 			<strong class="krumo-class"><?php echo get_class($data);?></strong>
 	</div>
@@ -1094,7 +1096,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _resource($data, $name) {
+  static Function _resource($data, $name) {
 ?>
 <li class="krumo-child">
 
@@ -1102,7 +1104,8 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 		onMouseOver="krumo.over(this);"
 		onMouseOut="krumo.out(this);">
 		
-			<a class="krumo-name"><?php echo $name;?></a>
+			<?php /* DEVEL: added htmlSpecialChars */ ?>
+			<a class="krumo-name"><?php echo htmlSpecialChars($name);?></a>
 			(<em class="krumo-type">Resource</em>) 
 			<strong class="krumo-resource"><?php echo get_resource_type($data);?></strong>
 	</div>
@@ -1121,7 +1124,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _boolean($data, $name) {
+  static Function _boolean($data, $name) {
 ?>
 <li class="krumo-child">
 
@@ -1129,7 +1132,8 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 		onMouseOver="krumo.over(this);"
 		onMouseOut="krumo.out(this);">
 		
-			<a class="krumo-name"><?php echo $name;?></a>
+			<?php /* DEVEL: added htmlSpecialChars */ ?>
+			<a class="krumo-name"><?php echo htmlSpecialChars($name);?></a>
 			(<em class="krumo-type">Boolean</em>) 
 			<strong class="krumo-boolean"><?php echo $data?'TRUE':'FALSE'?></strong>
 	</div>
@@ -1148,7 +1152,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _integer($data, $name) {
+  static Function _integer($data, $name) {
 ?>
 <li class="krumo-child">
 
@@ -1156,7 +1160,8 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 		onMouseOver="krumo.over(this);"
 		onMouseOut="krumo.out(this);">
 		
-			<a class="krumo-name"><?php echo $name;?></a>
+			<?php /* DEVEL: added htmlSpecialChars */ ?>
+			<a class="krumo-name"><?php echo htmlSpecialChars($name);?></a>
 			(<em class="krumo-type">Integer</em>)
 			<strong class="krumo-integer"><?php echo $data;?></strong> 
 	</div>
@@ -1175,7 +1180,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _float($data, $name) {
+  static Function _float($data, $name) {
 ?>
 <li class="krumo-child">
 
@@ -1183,7 +1188,8 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 		onMouseOver="krumo.over(this);"
 		onMouseOut="krumo.out(this);">
 		
-			<a class="krumo-name"><?php echo $name;?></a>
+			<?php /* DEVEL: added htmlSpecialChars */ ?>
+			<a class="krumo-name"><?php echo htmlSpecialChars($name);?></a>
 			(<em class="krumo-type">Float</em>) 
 			<strong class="krumo-float"><?php echo $data;?></strong>
 	</div>
@@ -1202,7 +1208,7 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 	* @access private
 	* @static
 	*/
-	Function _string($data, $name) {
+  static Function _string($data, $name) {
 
 		// extra ?
 		//
@@ -1220,7 +1226,8 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
 		onMouseOver="krumo.over(this);"
 		onMouseOut="krumo.out(this);">
 
-			<a class="krumo-name"><?php echo $name;?></a>
+			<?php /* DEVEL: added htmlSpecialChars */ ?>
+			<a class="krumo-name"><?php echo htmlSpecialChars($name);?></a>
 			(<em class="krumo-type">String,
 				<strong class="krumo-string-length"><?php
 					echo strlen($data) ?> characters</strong> </em>)
